@@ -28,34 +28,34 @@
  * represents one codec of a media line.
  * @defvar __payload_t
  */
-  typedef struct __payload __payload_t;
+typedef struct __payload __payload_t;
 
-  struct __payload
-  {
-    char *payload;
-    /*  char *port; this must be assigned by the application dynamicly */
-    char *number_of_port;
-    char *proto;
-    char *c_nettype;
-    char *c_addrtype;
-    char *c_addr;
-    char *c_addr_multicast_ttl;
-    char *c_addr_multicast_int;
-    /* rtpmap (rcvonly and other attributes are added dynamicly) */
-    char *a_rtpmap;
-  };
+struct __payload
+{
+  char *payload;
+  /*  char *port; this must be assigned by the application dynamicly */
+  char *number_of_port;
+  char *proto;
+  char *c_nettype;
+  char *c_addrtype;
+  char *c_addr;
+  char *c_addr_multicast_ttl;
+  char *c_addr_multicast_int;
+  /* rtpmap (rcvonly and other attributes are added dynamicly) */
+  char *a_rtpmap;
+};
 
 
 /**
  * Allocate a payload element.
  * @param payload The payload.
  */
-  int __payload_init (__payload_t ** payload);
+int __payload_init (__payload_t ** payload);
 /**
  * Free a payload element.
  * @param payload The payload.
  */
-  void __payload_free (__payload_t * payload);
+void __payload_free (__payload_t * payload);
 
 
 #ifdef OSIP_MT
@@ -78,36 +78,36 @@
 /* HAVE_PTHREAD_H is not used any more! I keep it for a while... */
 #if defined(HAVE_PTHREAD) || defined(HAVE_PTHREAD_H) || defined(HAVE_PTH_PTHREAD_H)
 #include <pthread.h>
-  typedef pthread_mutex_t osip_mutex_t;
+typedef pthread_mutex_t osip_mutex_t;
 #endif
 
 #ifdef __VXWORKS_OS__
-  typedef
-  {
-    int id;
-  }
-  osip_thread_t;
+typedef
+{
+  int id;
+}
+osip_thread_t;
 #endif
 
 #if defined(WIN32) || defined(_WIN32_WCE)
-  typedef struct 
-  {
-    HANDLE h;
-    unsigned id;
-   }
-   osip_thread_t;
-  
+typedef struct
+{
+  HANDLE h;
+  unsigned id;
+}
+osip_thread_t;
+
 #elif defined(__PSOS__)
-    typedef struct
-  {
-    unsigned long tid;
-  }
-  osip_thread_t;
+typedef struct
+{
+  unsigned long tid;
+}
+osip_thread_t;
 #endif
 
 #if !defined(WIN32) && !defined(_WIN32_WCE) && !defined(__VXWORKS_OS__) && !defined(__POS__)
 #if defined(HAVE_PTHREAD) || defined(HAVE_PTHREAD_H) || defined(HAVE_PTH_PTHREAD_H)
-  typedef pthread_t osip_thread_t;
+typedef pthread_t osip_thread_t;
 #else
 #error no thread implementation found!
 #endif
@@ -118,38 +118,38 @@
 
 #if defined(WIN32) || defined(_WIN32_WCE)
 #include <windows.h>
-  typedef struct 
-  {
-    HANDLE h;
-  }
-  osip_mutex_t;
-  typedef struct
-  {
-    HANDLE h;
-  }
-  osip_sem_t;
+typedef struct
+{
+  HANDLE h;
+}
+osip_mutex_t;
+typedef struct
+{
+  HANDLE h;
+}
+osip_sem_t;
 #endif
 
 #if (!(defined(WIN32) || defined (_WIN32_WCE)) && defined(__PSOS__))
 #include <Types.h>
 #include <os.h>
-  typedef struct
-  {
-    UInt32 id;
-  }
-  osip_mutex_t;
-  typedef struct
-  {
-    UInt32 id;
-  }
-  osip_sem_t;
+typedef struct
+{
+  UInt32 id;
+}
+osip_mutex_t;
+typedef struct
+{
+  UInt32 id;
+}
+osip_sem_t;
 #endif
 
 #ifdef __VXWORKS_OS__
 #include <semaphore.h>
 #include <semLib.h>
-  typedef struct semaphore osip_mutex_t;
-  typedef sem_t osip_sem_t;
+typedef struct semaphore osip_mutex_t;
+typedef sem_t osip_sem_t;
 #endif
 
 #ifdef __sun__
@@ -159,7 +159,7 @@
 #endif
 
 
-#if defined(HAVE_SEMAPHORE_H)
+#if defined(HAVE_SEMAPHORE_H) && !defined(__APPLE_CC__)
 #include <semaphore.h>
 #ifdef __sun__
 #undef getdate
@@ -169,18 +169,17 @@
  * Structure for referencing a semaphore element.
  * @defvar osip_sem_t
  */
-  typedef sem_t osip_sem_t;
-#endif
+typedef sem_t osip_sem_t;
 
-#if !defined(HAVE_SEMAPHORE_H) && defined(HAVE_SYS_SEM_H)
+#elif defined(HAVE_SYS_SEM_H)
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/sem.h>
-  typedef struct
-  {
-    int semid;
-  }
-  osip_sem_t;
+typedef struct
+{
+  int semid;
+}
+osip_sem_t;
 #endif
 
 #if (!defined(HAVE_SEMAPHORE_H) && !defined(HAVE_SYS_SEM_H) && !defined(WIN32) && !defined(_WIN32_WCE) && !defined(__PSOS__) && !defined(__VXWORKS_OS__))
@@ -198,19 +197,19 @@
  * @defvar struct osip_cond
  */
 #if defined(HAVE_PTHREAD) || defined(HAVE_PTH_PTHREAD_H)
-  typedef struct osip_cond
-  {
-    pthread_cond_t cv;
-  } osip_cond_t;
+typedef struct osip_cond
+{
+  pthread_cond_t cv;
+} osip_cond_t;
 
 #endif
-  
+
 #ifdef WIN32
-  typedef struct osip_cond
-  {
-    struct osip_mutex * mut;
-    struct osip_sem * sem;
-  } osip_cond_t;
+typedef struct osip_cond
+{
+  struct osip_mutex *mut;
+  struct osip_sem *sem;
+} osip_cond_t;
 #endif
 
 #endif
