@@ -25,6 +25,10 @@
 
 #include <time.h>
 
+#ifdef WIN32
+#include <Winsock.h>
+#endif
+
 #ifdef __sun
 #include <sys/types.h>
 #endif
@@ -388,15 +392,6 @@ extern "C"
   }
   type_t;
 
-#if 0
-  typedef struct osip_statemachine osip_statemachine_t;
-
-  struct osip_statemachine
-  {
-    osip_list_t *transitions;
-  };
-#endif
-
 /**
  * Enumeration for transaction type.
  * A transaction can be either of:
@@ -446,23 +441,14 @@ extern "C"
   struct osip_ict
   {
     /* state machine is implied... */
-#ifdef NEW_TIMER
-    int            timer_a_length; /* A=T1, A=2xT1... (unreliable tr only)  */
+    int timer_a_length;		/* A=T1, A=2xT1... (unreliable tr only)  */
     struct timeval timer_a_start;
-    int            timer_b_length; /* B = 64* T1                            */
-    struct timeval timer_b_start;  /* fire when transaction timeouts        */
-    int            timer_d_length; /* D >= 32s for unreliable tr (or 0)     */
-    struct timeval timer_d_start;  /* should be equal to timer H            */
-#else
-    int timer_a_length;	   /* A=T1, A=2xT1... (unreliable transport only)  */
-    time_t timer_a_start;
-    int timer_b_length;	   /* B = 64* T1                                   */
-    time_t timer_b_start;  /* fire when transaction timeouts               */
-    int timer_d_length;    /* D >= 32s for unreliable transport (else = 0) */
-    time_t timer_d_start;  /* should be equal to timer H                   */
-#endif
-    char *destination;	   /* url used to send requests         */
-    int port;		   /* port of next hop                  */
+    int timer_b_length;		/* B = 64* T1                            */
+    struct timeval timer_b_start;	/* fire when transaction timeouts        */
+    int timer_d_length;		/* D >= 32s for unreliable tr (or 0)     */
+    struct timeval timer_d_start;	/* should be equal to timer H            */
+    char *destination;		/* url used to send requests         */
+    int port;			/* port of next hop                  */
 
   };
 
@@ -476,23 +462,14 @@ extern "C"
   {
     /* state machine is implied... */
 
-#ifdef NEW_TIMER
-    int            timer_e_length; /* A=T1, A=2xT1... (unreliable tr. only) */
-    struct timeval timer_e_start;  /*  (else = -1) not active               */
-    int            timer_f_length; /* B = 64* T1                            */
-    struct timeval timer_f_start;  /* fire when transaction timeouts        */
-    int            timer_k_length; /* K = T4 (else = 0)                     */
+    int timer_e_length;		/* A=T1, A=2xT1... (unreliable tr. only) */
+    struct timeval timer_e_start;	/*  (else = -1) not active               */
+    int timer_f_length;		/* B = 64* T1                            */
+    struct timeval timer_f_start;	/* fire when transaction timeouts        */
+    int timer_k_length;		/* K = T4 (else = 0)                     */
     struct timeval timer_k_start;
-#else
-    int timer_e_length;    /* A=T1, A=2xT1... (unreliable transport only)  */
-    time_t timer_e_start;  /*  (else = -1) not active                      */
-    int timer_f_length;	   /* B = 64* T1                                   */
-    time_t timer_f_start;  /* fire when transaction timeouts               */
-    int timer_k_length;	   /* K = T4 (else = 0)                            */
-    time_t timer_k_start;
-#endif
-    char *destination;	   /* url used to send requests         */
-    int port;		   /* port of next hop                  */
+    char *destination;		/* url used to send requests         */
+    int port;			/* port of next hop                  */
 
   };
 
@@ -504,21 +481,12 @@ extern "C"
 
   struct osip_ist
   {
-#ifdef NEW_TIMER
-    int            timer_g_length; /* G=MIN(T1*2,T2) for unreliable trans.  */
-    struct timeval timer_g_start;  /* 0 when reliable transport is used!    */
-    int            timer_h_length; /* H = 64* T1                            */
-    struct timeval timer_h_start;  /* fire when if no ACK is received       */
-    int            timer_i_length; /* I = T4 for unreliable transport (or 0)*/
-    struct timeval timer_i_start;  /* absorb all ACK                        */
-#else
-    int timer_g_length;   /* G=MIN(T1*2,T2) for unreliable transport    */
-    time_t timer_g_start; /* else = 0 when reliable transport is used!  */
-    int timer_h_length;	  /* H = 64* T1                                 */
-    time_t timer_h_start; /* fire when if no ACK is received            */
-    int timer_i_length;	  /* I = T4 for unreliable transport (else = 0) */
-    time_t timer_i_start; /* absorb all ACK                             */
-#endif
+    int timer_g_length;		/* G=MIN(T1*2,T2) for unreliable trans.  */
+    struct timeval timer_g_start;	/* 0 when reliable transport is used!    */
+    int timer_h_length;		/* H = 64* T1                            */
+    struct timeval timer_h_start;	/* fire when if no ACK is received       */
+    int timer_i_length;		/* I = T4 for unreliable transport (or 0) */
+    struct timeval timer_i_start;	/* absorb all ACK                        */
   };
 
 /**
@@ -529,13 +497,8 @@ extern "C"
 
   struct osip_nist
   {
-#ifdef NEW_TIMER
-    int            timer_j_length; /* J = 64*T1 (else 0) */
-    struct timeval timer_j_start;
-#else
     int timer_j_length;		/* J = 64*T1 (else 0) */
-    time_t timer_j_start;
-#endif
+    struct timeval timer_j_start;
   };
 
 /**
@@ -559,7 +522,7 @@ extern "C"
 
     osip_message_t *orig_request;	/* last request sent                 */
     osip_message_t *last_response;	/* last response received            */
-    osip_message_t *ack;			/* ack request sent                  */
+    osip_message_t *ack;	/* ack request sent                  */
 
     state_t state;		/* state of transaction              */
 
@@ -581,95 +544,108 @@ extern "C"
   };
 
 
-  typedef enum osip_message_callback_type {
-    OSIP_ICT_INVITE_SENT = 0,
-    OSIP_ICT_INVITE_SENT_AGAIN,
-    OSIP_ICT_ACK_SENT,
-    OSIP_ICT_ACK_SENT_AGAIN,
-    OSIP_ICT_STATUS_1XX_RECEIVED,
-    OSIP_ICT_STATUS_2XX_RECEIVED,
-    OSIP_ICT_STATUS_2XX_RECEIVED_AGAIN,
-    OSIP_ICT_STATUS_3XX_RECEIVED,
-    OSIP_ICT_STATUS_4XX_RECEIVED,
-    OSIP_ICT_STATUS_5XX_RECEIVED,
-    OSIP_ICT_STATUS_6XX_RECEIVED,
-    OSIP_ICT_STATUS_3456XX_RECEIVED_AGAIN,
+/**
+ * Enumeration for callback type.
+ */
+  typedef enum osip_message_callback_type
+  {
+    OSIP_ICT_INVITE_SENT = 0,               /**< INVITE MESSAGE SENT */
+    OSIP_ICT_INVITE_SENT_AGAIN,             /**< INVITE MESSAGE RETRANSMITTED */
+    OSIP_ICT_ACK_SENT,                      /**< ACK MESSAGE SENT */
+    OSIP_ICT_ACK_SENT_AGAIN,                /**< ACK MESSAGE RETRANSMITTED */
+    OSIP_ICT_STATUS_1XX_RECEIVED,           /**< 1XX FOR INVITE RECEIVED */
+    OSIP_ICT_STATUS_2XX_RECEIVED,           /**< 2XX FOR INVITE RECEIVED */
+    OSIP_ICT_STATUS_2XX_RECEIVED_AGAIN,     /**< 2XX FOR INVITE RECEIVED AGAIN */
+    OSIP_ICT_STATUS_3XX_RECEIVED,           /**< 3XX FOR INVITE RECEIVED */
+    OSIP_ICT_STATUS_4XX_RECEIVED,           /**< 4XX FOR INVITE RECEIVED */
+    OSIP_ICT_STATUS_5XX_RECEIVED,           /**< 5XX FOR INVITE RECEIVED */
+    OSIP_ICT_STATUS_6XX_RECEIVED,           /**< 6XX FOR INVITE RECEIVED */
+    OSIP_ICT_STATUS_3456XX_RECEIVED_AGAIN,  /**< RESPONSE RECEIVED AGAIN */
 
-    OSIP_IST_INVITE_RECEIVED,
-    OSIP_IST_INVITE_RECEIVED_AGAIN,
-    OSIP_IST_ACK_RECEIVED,
-    OSIP_IST_ACK_RECEIVED_AGAIN,
-    OSIP_IST_STATUS_1XX_SENT,
-    OSIP_IST_STATUS_2XX_SENT,
-    OSIP_IST_STATUS_2XX_SENT_AGAIN,
-    OSIP_IST_STATUS_3XX_SENT,
-    OSIP_IST_STATUS_4XX_SENT,
-    OSIP_IST_STATUS_5XX_SENT,
-    OSIP_IST_STATUS_6XX_SENT,
-    OSIP_IST_STATUS_3456XX_SENT_AGAIN,
+    OSIP_IST_INVITE_RECEIVED,               /**< INVITE MESSAGE RECEIVED */
+    OSIP_IST_INVITE_RECEIVED_AGAIN,         /**< INVITE MESSAGE RECEIVED AGAN */
+    OSIP_IST_ACK_RECEIVED,                  /**< ACK MESSAGE RECEIVED */
+    OSIP_IST_ACK_RECEIVED_AGAIN,            /**< ACK MESSAGE RECEIVED AGAIN */
+    OSIP_IST_STATUS_1XX_SENT,               /**< 1XX FOR INVITE SENT */
+    OSIP_IST_STATUS_2XX_SENT,               /**< 2XX FOR INVITE SENT */
+    OSIP_IST_STATUS_2XX_SENT_AGAIN,         /**< 2XX FOR INVITE RETRANSMITTED */
+    OSIP_IST_STATUS_3XX_SENT,               /**< 3XX FOR INVITE SENT */
+    OSIP_IST_STATUS_4XX_SENT,               /**< 4XX FOR INVITE SENT */
+    OSIP_IST_STATUS_5XX_SENT,               /**< 5XX FOR INVITE SENT */
+    OSIP_IST_STATUS_6XX_SENT,               /**< 6XX FOR INVITE SENT */
+    OSIP_IST_STATUS_3456XX_SENT_AGAIN,      /**< RESPONSE RETRANSMITTED */
 
-    OSIP_NICT_REGISTER_SENT,
-    OSIP_NICT_BYE_SENT,
-    OSIP_NICT_OPTIONS_SENT,
-    OSIP_NICT_INFO_SENT,
-    OSIP_NICT_CANCEL_SENT,
-    OSIP_NICT_NOTIFY_SENT,
-    OSIP_NICT_SUBSCRIBE_SENT,
-    OSIP_NICT_UNKNOWN_REQUEST_SENT,
-    OSIP_NICT_REQUEST_SENT_AGAIN,
-    OSIP_NICT_STATUS_1XX_RECEIVED,
-    OSIP_NICT_STATUS_2XX_RECEIVED,
-    OSIP_NICT_STATUS_2XX_RECEIVED_AGAIN,
-    OSIP_NICT_STATUS_3XX_RECEIVED,
-    OSIP_NICT_STATUS_4XX_RECEIVED,
-    OSIP_NICT_STATUS_5XX_RECEIVED,
-    OSIP_NICT_STATUS_6XX_RECEIVED,
-    OSIP_NICT_STATUS_3456XX_RECEIVED_AGAIN,
+    OSIP_NICT_REGISTER_SENT,                /**< REGISTER MESSAGE SENT */
+    OSIP_NICT_BYE_SENT,                     /**< BYE MESSAGE SENT */
+    OSIP_NICT_OPTIONS_SENT,                 /**< OPTIONS MESSAGE SENT */
+    OSIP_NICT_INFO_SENT,                    /**< INFO MESSAGE SENT */
+    OSIP_NICT_CANCEL_SENT,                  /**< CANCEL MESSAGE SENT */
+    OSIP_NICT_NOTIFY_SENT,                  /**< NOTIFY MESSAGE SENT */
+    OSIP_NICT_SUBSCRIBE_SENT,               /**< SUBSCRIBE MESSAGE SENT */
+    OSIP_NICT_UNKNOWN_REQUEST_SENT,         /**< UNKNOWN REQUEST MESSAGE SENT */
+    OSIP_NICT_REQUEST_SENT_AGAIN,           /**< REQUEST MESSAGE RETRANMITTED */
+    OSIP_NICT_STATUS_1XX_RECEIVED,          /**< 1XX FOR MESSAGE RECEIVED */
+    OSIP_NICT_STATUS_2XX_RECEIVED,          /**< 2XX FOR MESSAGE RECEIVED */
+    OSIP_NICT_STATUS_2XX_RECEIVED_AGAIN,    /**< 2XX FOR MESSAGE RECEIVED AGAIN */
+    OSIP_NICT_STATUS_3XX_RECEIVED,          /**< 3XX FOR MESSAGE RECEIVED */
+    OSIP_NICT_STATUS_4XX_RECEIVED,          /**< 4XX FOR MESSAGE RECEIVED */
+    OSIP_NICT_STATUS_5XX_RECEIVED,          /**< 5XX FOR MESSAGE RECEIVED */
+    OSIP_NICT_STATUS_6XX_RECEIVED,          /**< 6XX FOR MESSAGE RECEIVED */
+    OSIP_NICT_STATUS_3456XX_RECEIVED_AGAIN, /**< RESPONSE RECEIVED AGAIN */
 
-    OSIP_NIST_REGISTER_RECEIVED,
-    OSIP_NIST_BYE_RECEIVED,
-    OSIP_NIST_OPTIONS_RECEIVED,
-    OSIP_NIST_INFO_RECEIVED,
-    OSIP_NIST_CANCEL_RECEIVED,
-    OSIP_NIST_NOTIFY_RECEIVED,
-    OSIP_NIST_SUBSCRIBE_RECEIVED,
-    /* ... TO BE ADDED: All known and used method extensions */
-    OSIP_NIST_UNKNOWN_REQUEST_RECEIVED,
-    OSIP_NIST_REQUEST_RECEIVED_AGAIN,
-    OSIP_NIST_STATUS_1XX_SENT,
-    OSIP_NIST_STATUS_2XX_SENT,
-    OSIP_NIST_STATUS_2XX_SENT_AGAIN,
-    OSIP_NIST_STATUS_3XX_SENT,
-    OSIP_NIST_STATUS_4XX_SENT,
-    OSIP_NIST_STATUS_5XX_SENT,
-    OSIP_NIST_STATUS_6XX_SENT,
-    OSIP_NIST_STATUS_3456XX_SENT_AGAIN,
+    OSIP_NIST_REGISTER_RECEIVED,            /**< REGISTER RECEIVED */
+    OSIP_NIST_BYE_RECEIVED,                 /**< BYE RECEIVED */
+    OSIP_NIST_OPTIONS_RECEIVED,             /**< OPTIONS RECEIVED */
+    OSIP_NIST_INFO_RECEIVED,                /**< INFO RECEIVED */
+    OSIP_NIST_CANCEL_RECEIVED,              /**< CANCEL RECEIVED */
+    OSIP_NIST_NOTIFY_RECEIVED,              /**< NOTIFY RECEIVED */
+    OSIP_NIST_SUBSCRIBE_RECEIVED,           /**< SUBSCRIBE RECEIVED */
 
-    OSIP_MESSAGE_CALLBACK_COUNT
+    OSIP_NIST_UNKNOWN_REQUEST_RECEIVED,     /**< UNKNWON REQUEST RECEIVED */
+    OSIP_NIST_REQUEST_RECEIVED_AGAIN,       /**< UNKNWON REQUEST RECEIVED AGAIN */
+    OSIP_NIST_STATUS_1XX_SENT,              /**< 1XX FOR MESSAGE SENT */
+    OSIP_NIST_STATUS_2XX_SENT,              /**< 2XX FOR MESSAGE SENT */
+    OSIP_NIST_STATUS_2XX_SENT_AGAIN,        /**< 2XX FOR MESSAGE RETRANSMITTED */
+    OSIP_NIST_STATUS_3XX_SENT,              /**< 3XX FOR MESSAGE SENT */
+    OSIP_NIST_STATUS_4XX_SENT,              /**< 4XX FOR MESSAGE SENT */
+    OSIP_NIST_STATUS_5XX_SENT,              /**< 5XX FOR MESSAGE SENT */
+    OSIP_NIST_STATUS_6XX_SENT,              /**< 6XX FOR MESSAGE SENT */
+    OSIP_NIST_STATUS_3456XX_SENT_AGAIN,     /**< RESPONSE RETRANSMITTED */
+
+    OSIP_MESSAGE_CALLBACK_COUNT             /**< END OF ENUM */
   } osip_message_callback_type_t;
 
-  typedef enum osip_kill_callback_type {
-    OSIP_ICT_KILL_TRANSACTION,
-    OSIP_IST_KILL_TRANSACTION,
-    OSIP_NICT_KILL_TRANSACTION,
-    OSIP_NIST_KILL_TRANSACTION,
+/**
+ * Enumeration for callback type used when transaction is over.
+ */
+  typedef enum osip_kill_callback_type
+  {
+    OSIP_ICT_KILL_TRANSACTION,      /**< end of Client INVITE transaction */
+    OSIP_IST_KILL_TRANSACTION,      /**< end of Server INVITE transaction */
+    OSIP_NICT_KILL_TRANSACTION,     /**< end of Client Non-INVITE transaction */
+    OSIP_NIST_KILL_TRANSACTION,     /**< end of Server Non-INVITE transaction */
 
-    OSIP_KILL_CALLBACK_COUNT
+    OSIP_KILL_CALLBACK_COUNT        /**< END OF ENUM */
   } osip_kill_callback_type_t;
 
-  typedef enum osip_transport_error_callback_type {
-    OSIP_ICT_TRANSPORT_ERROR,
-    OSIP_IST_TRANSPORT_ERROR,
-    OSIP_NICT_TRANSPORT_ERROR,
-    OSIP_NIST_TRANSPORT_ERROR,
+/**
+ * Enumeration for callback type used when a transport error is detected.
+ */
+  typedef enum osip_transport_error_callback_type
+  {
+    OSIP_ICT_TRANSPORT_ERROR,             /**< transport error for ICT */
+    OSIP_IST_TRANSPORT_ERROR,             /**< transport error for IST */
+    OSIP_NICT_TRANSPORT_ERROR,            /**< transport error for NICT */
+    OSIP_NIST_TRANSPORT_ERROR,            /**< transport error for NIST */
 
-    OSIP_TRANSPORT_ERROR_CALLBACK_COUNT
+    OSIP_TRANSPORT_ERROR_CALLBACK_COUNT   /**< END OF ENUM */
   } osip_transport_error_callback_type_t;
 
-  typedef void (* osip_message_cb_t) (int type, osip_transaction_t *, osip_message_t *);
-  typedef void (* osip_kill_transaction_cb_t) (int type, osip_transaction_t *);
-  typedef void (* osip_transport_error_cb_t) (int type, osip_transaction_t *,
-					      int error);
+  typedef void (*osip_message_cb_t) (int type, osip_transaction_t *,
+				     osip_message_t *);
+  typedef void (*osip_kill_transaction_cb_t) (int type, osip_transaction_t *);
+  typedef void (*osip_transport_error_cb_t) (int type, osip_transaction_t *,
+					     int error);
 
 
 #ifdef OSIP_RETRANSMIT_2XX
@@ -679,16 +655,16 @@ extern "C"
 
   struct ixt_t
   {
-    /* any ACK received that match this context will set counter to -1*/
+    /* any ACK received that match this context will set counter to -1 */
     struct osip_dialog *dialog;
-    osip_message_t *msg2xx;    /* copy of string to retransmit */
-    osip_message_t *ack;       /* useless for ist */
+    osip_message_t *msg2xx;	/* copy of string to retransmit */
+    osip_message_t *ack;	/* useless for ist */
     time_t start;
-    int interval;     /* between each retransmission, in ms */
+    int interval;		/* between each retransmission, in ms */
     char *dest;
     int port;
     int sock;
-    int counter;      /* start at 7 */
+    int counter;		/* start at 7 */
   };
 
 #endif
@@ -712,21 +688,43 @@ extern "C"
     osip_list_t *osip_ist_transactions;
     osip_list_t *osip_nict_transactions;
     osip_list_t *osip_nist_transactions;
-    
-    osip_list_t *ixt_retransmissions; /* for retransmission of 2xx & ACK for INVITE */
+
+    osip_list_t *ixt_retransmissions;	/* for retransmission of 2xx & ACK for INVITE */
 
     osip_message_cb_t msg_callbacks[OSIP_MESSAGE_CALLBACK_COUNT];
     osip_kill_transaction_cb_t kill_callbacks[OSIP_KILL_CALLBACK_COUNT];
-    osip_transport_error_cb_t tp_error_callbacks[OSIP_TRANSPORT_ERROR_CALLBACK_COUNT];
+    osip_transport_error_cb_t
+      tp_error_callbacks[OSIP_TRANSPORT_ERROR_CALLBACK_COUNT];
 
     /* callbacks for sending messages */
-    int (*cb_send_message) (osip_transaction_t *, osip_message_t *, char *, int, int);
+    int (*cb_send_message) (osip_transaction_t *, osip_message_t *, char *,
+			    int, int);
   };
 
-  int osip_set_message_callback (osip_t *, int type, osip_message_cb_t cb);
-  int osip_set_kill_transaction_callback (osip_t *, int type,
+/**
+ * Set a callback for each transaction operation. 
+ * @param osip The element to work on.
+ * @param type The event type to hook on.
+ * @param cb The method to be called upon the event.
+ */
+  int osip_set_message_callback (osip_t *osip, int type, osip_message_cb_t cb);
+
+/**
+ * Set a callback for transaction operation related to the end of transactions. 
+ * @param osip The element to work on.
+ * @param type The event type to hook on.
+ * @param cb The method to be called upon the event.
+ */
+  int osip_set_kill_transaction_callback (osip_t *osip, int type,
 					  osip_kill_transaction_cb_t cb);
-  int osip_set_transport_error_callback (osip_t *, int type,
+
+/**
+ * Set a callback for each transaction operation related to network error.
+ * @param osip The element to work on.
+ * @param type The event type to hook on.
+ * @param cb The method to be called upon the event.
+ */
+  int osip_set_transport_error_callback (osip_t *osip, int type,
 					 osip_transport_error_cb_t cb);
 
 /**
@@ -755,8 +753,9 @@ extern "C"
  * @param osip The global instance of oSIP.
  * @param request The SIP request that initiate the transaction.
  */
-  int osip_transaction_init (osip_transaction_t ** transaction, osip_fsm_type_t ctx_type,
-			     osip_t * osip, osip_message_t * request);
+  int osip_transaction_init (osip_transaction_t ** transaction,
+			     osip_fsm_type_t ctx_type, osip_t * osip,
+			     osip_message_t * request);
 /**
  * Free all resource in a osip_transaction_t element.
  * @param transaction The element to free.
@@ -780,7 +779,8 @@ extern "C"
  * @param destination The destination host.
  * @param port The destination port.
  */
-  int osip_ict_set_destination (osip_ict_t * ict, char *destination, int port);
+  int osip_ict_set_destination (osip_ict_t * ict, char *destination,
+				int port);
 
 /**
  * Set the host and port destination used for sending the SIP message.
@@ -791,14 +791,16 @@ extern "C"
  * @param destination The destination host.
  * @param port The destination port.
  */
-  int osip_nict_set_destination (osip_nict_t * nict, char *destination, int port);
+  int osip_nict_set_destination (osip_nict_t * nict, char *destination,
+				 int port);
 
 /**
  * Add a SIP event in the fifo of a osip_transaction_t element.
  * @param transaction The element to work on.
  * @param evt The event to add.
  */
-  int osip_transaction_add_event (osip_transaction_t * transaction, osip_event_t * evt);
+  int osip_transaction_add_event (osip_transaction_t * transaction,
+				  osip_event_t * evt);
 /**
  * Consume one osip_event_t element previously added in the fifo.
  * NOTE: This method MUST NEVER be called within another call
@@ -807,7 +809,8 @@ extern "C"
  * @param transaction The element to free.
  * @param evt The element to consume.
  */
-  int osip_transaction_execute (osip_transaction_t * transaction, osip_event_t * evt);
+  int osip_transaction_execute (osip_transaction_t * transaction,
+				osip_event_t * evt);
 /**
  * Set a pointer to your personal context associated with this transaction.
  * NOTE: this is a very useful method that allow you to avoid searching
@@ -820,7 +823,7 @@ extern "C"
  * @param instance The address of your context.
  */
   int osip_transaction_set_your_instance (osip_transaction_t * transaction,
-				     void *instance);
+					  void *instance);
 /**
  * Get a pointer to your personal context associated with this transaction.
  * @param transaction The element to work on.
@@ -834,7 +837,8 @@ extern "C"
  * @param ip The ip of host where to send initial request.
  * @param port The port where to send initial request.
  */
-  int osip_transaction_get_destination(osip_transaction_t * transaction, char **ip, int *port);
+  int osip_transaction_get_destination (osip_transaction_t * transaction,
+					char **ip, int *port);
 
 #ifndef DOXYGEN
 
@@ -844,14 +848,16 @@ extern "C"
  * @param transaction The element to work on.
  * @param sock The socket for incoming message.
  */
-  int osip_transaction_set_in_socket (osip_transaction_t * transaction, int sock);
+  int osip_transaction_set_in_socket (osip_transaction_t * transaction,
+				      int sock);
 /**
  * Set the socket for outgoing message.
  * NOTE: THIS HAS NEVER TESTED! Please send feedback.
  * @param transaction The element to work on.
  * @param sock The socket for outgoing message.
  */
-  int osip_transaction_set_out_socket (osip_transaction_t * transaction, int sock);
+  int osip_transaction_set_out_socket (osip_transaction_t * transaction,
+				       int sock);
 
 
 #if 0
@@ -865,7 +871,8 @@ extern "C"
  * @param to2 The new to header.
  * @param from2 The new from header.
  */
-  int callleg_match (osip_to_t * to1, osip_from_t * from1, osip_to_t * to2, osip_from_t * from2);
+  int callleg_match (osip_to_t * to1, osip_from_t * from1, osip_to_t * to2,
+		     osip_from_t * from2);
 
 #endif
 
@@ -928,7 +935,6 @@ extern "C"
  */
   int osip_nist_execute (osip_t * osip);
 
-#ifdef NEW_TIMER
 /**
  * Retreive the minimum timer value to be used by an application
  * so that the osip_timer_*_execute method don't have to be called
@@ -937,8 +943,8 @@ extern "C"
  * @param osip The element to work on.
  * @param lower_tv The minimum timer when the application should wake up.
  */
-  void osip_timers_gettimeout(osip_t * osip, struct timeval *lower_tv);
-#endif
+  void osip_timers_gettimeout (osip_t * osip, struct timeval *lower_tv);
+
 /**
  * Check if an ict transactions needs a timer event.
  * @param osip The element to work on.
@@ -968,7 +974,7 @@ extern "C"
  */
   osip_transaction_t *osip_transaction_find (osip_list_t * transactions,
 					     osip_event_t * evt);
-  
+
 
 #ifndef DOXYGEN
 /**
@@ -979,7 +985,8 @@ extern "C"
  * @param evt The element representing the SIP MESSAGE.
  */
 #ifndef OSIP_MT
-  osip_transaction_t *osip_find_transaction (osip_t * osip, osip_event_t * evt);
+  osip_transaction_t *osip_find_transaction (osip_t * osip,
+					     osip_event_t * evt);
 #endif
 
   osip_transaction_t *__osip_find_transaction (osip_t * osip,
@@ -1000,7 +1007,8 @@ extern "C"
  * @param osip The element to work on.
  * @param evt The element representing the new SIP REQUEST.
  */
-  osip_transaction_t *osip_create_transaction (osip_t * osip, osip_event_t * evt);
+  osip_transaction_t *osip_create_transaction (osip_t * osip,
+					       osip_event_t * evt);
 
 /**
  * Create a sipevent from a SIP message string.
@@ -1011,7 +1019,7 @@ extern "C"
 
 #ifdef OSIP_RETRANSMIT_2XX
 
-  void osip_retransmissions_execute(osip_t *osip);
+  void osip_retransmissions_execute (osip_t * osip);
 
 /**
  * Start out of fsm 200 Ok retransmissions. This is usefull for user-agents.
@@ -1020,7 +1028,9 @@ extern "C"
  * @param msg200ok The 200 ok response.
  * @param sock The socket to be used to send the message. (optional).
  */
-  void osip_start_200ok_retransmissions(osip_t *osip, struct osip_dialog *dialog, osip_message_t *msg200ok, int sock);
+  void osip_start_200ok_retransmissions (osip_t * osip,
+					 struct osip_dialog *dialog,
+					 osip_message_t * msg200ok, int sock);
 
 /**
  * Start out of fsm ACK retransmissions. This is usefull for user-agents.
@@ -1031,14 +1041,17 @@ extern "C"
  * @param sock The destination port.
  * @param sock The socket to be used to send the message. (optional).
  */
-  void osip_start_ack_retransmissions(osip_t *osip, struct osip_dialog *dialog, osip_message_t *ack, char *dest, int port, int sock);
+  void osip_start_ack_retransmissions (osip_t * osip,
+				       struct osip_dialog *dialog,
+				       osip_message_t * ack, char *dest,
+				       int port, int sock);
 
 /**
  * Stop the out of fsm 200 Ok retransmissions matching an incoming ACK.
  * @param osip The osip_t structure.
  * @param ack  The ack that has just been received.
  */
-  void osip_stop_200ok_retransmissions(osip_t *osip, osip_message_t *ack);
+  void osip_stop_200ok_retransmissions (osip_t * osip, osip_message_t * ack);
 
 /**
  * Stop out of fsm retransmissions (ACK or 200 Ok) associated to a given dialog.
@@ -1047,7 +1060,8 @@ extern "C"
  * @param osip The osip_t structure
  * @param dialog The dialog.
  */
-  void osip_stop_retransmissions_from_dialog(osip_t *osip, struct osip_dialog *dialog);
+  void osip_stop_retransmissions_from_dialog (osip_t * osip,
+					      struct osip_dialog *dialog);
 
 #endif
 
@@ -1061,7 +1075,7 @@ extern "C"
  * Free all ressource in a sipevent.
  * @param event The event to free.
  */
-  void osip_event_free( osip_event_t *event );
+  void osip_event_free (osip_event_t * event);
 
 /**
  * Register the callback used to send SIP message.
