@@ -55,20 +55,12 @@ __osip_nist_init (osip_nist_t ** nist, osip_t * osip, osip_message_t * invite)
     if (i != 0)
       {
 	(*nist)->timer_j_length = 64 * DEFAULT_T1;
-#ifdef NEW_TIMER
-	(*nist)->timer_j_start.tv_sec = -1; /* not started */
-#else
-	(*nist)->timer_j_start = -1;	/* not started */
-#endif
+	(*nist)->timer_j_start.tv_sec = -1;	/* not started */
       }
     else
       {				/* TCP is used: */
 	(*nist)->timer_j_length = 0;	/* MUST do the transition immediatly */
-#ifdef NEW_TIMER
-	(*nist)->timer_j_start.tv_sec = -1; /* not started */
-#else
-	(*nist)->timer_j_start = -1;	/* not started */
-#endif
+	(*nist)->timer_j_start.tv_sec = -1;	/* not started */
       }
   }
 
@@ -87,38 +79,18 @@ __osip_nist_free (osip_nist_t * nist)
   OSIP_TRACE (osip_trace
 	      (__FILE__, __LINE__, OSIP_INFO2, NULL,
 	       "free nist ressource\n"));
-  
+
   osip_free (nist);
   return 0;
 }
 
 
-#ifndef NEW_TIMER
-
-osip_event_t *
-__osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transactionid)
-{
-  time_t now = time (NULL);
-
-  if (nist == NULL)
-    return NULL;
-  if (state == NIST_COMPLETED)
-    {
-      if (nist->timer_j_start == -1)
-	return NULL;
-      if ((now - nist->timer_j_start) * 1000 > nist->timer_j_length)
-	return __osip_event_new (TIMEOUT_J, transactionid);
-    }
-  return NULL;
-}
-
-#else
 
 osip_event_t *
 __osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transactionid)
 {
   struct timeval now;
-  gettimeofday(&now, NULL);
+  gettimeofday (&now, NULL);
 
   if (nist == NULL)
     return NULL;
@@ -126,10 +98,9 @@ __osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transacti
     {
       if (nist->timer_j_start.tv_sec == -1)
 	return NULL;
-      if (timercmp(&now, &nist->timer_j_start, > ))
+      if (timercmp (&now, &nist->timer_j_start, >))
 	return __osip_event_new (TIMEOUT_J, transactionid);
     }
   return NULL;
 }
 
-#endif
