@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 #include "parser.h"
 
 
@@ -31,7 +32,7 @@ osip_message_set_accept_language (osip_message_t * sip, const char *hvalue)
   osip_accept_language_t *accept_language;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_accept_language_init (&accept_language);
@@ -43,16 +44,14 @@ osip_message_set_accept_language (osip_message_t * sip, const char *hvalue)
       osip_accept_language_free (accept_language);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->accept_languages, accept_language, -1);
   return 0;
 }
 
 int
 osip_message_get_accept_language (const osip_message_t * sip, int pos,
-			osip_accept_language_t ** dest)
+				  osip_accept_language_t ** dest)
 {
   osip_accept_language_t *accept_language;
 
