@@ -22,8 +22,14 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
+#include <osipparser2/osip_body.h>
 #include "parser.h"
 
+static int osip_body_parse_header (osip_body_t * body,
+				   const char *start_of_osip_body_header,
+				   const char **next_body);
+
 int
 osip_body_init (osip_body_t ** body)
 {
@@ -63,9 +69,7 @@ osip_message_set_body (osip_message_t * sip, const char *buf)
       osip_body_free (body);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->bodies, body, -1);
   return 0;
 }
@@ -122,7 +126,8 @@ bc_error1:
 /* OUTPUT: osip_body_t *body | structure to save results. */
 /* returns -1 on error. */
 int
-osip_message_get_body (const osip_message_t * sip, int pos, osip_body_t ** dest)
+osip_message_get_body (const osip_message_t * sip, int pos,
+		       osip_body_t ** dest)
 {
   osip_body_t *body;
 
@@ -158,7 +163,8 @@ osip_body_set_contenttype (osip_body_t * body, const char *hvalue)
 }
 
 int
-osip_body_set_header (osip_body_t * body, const char *hname, const char *hvalue)
+osip_body_set_header (osip_body_t * body, const char *hname,
+		      const char *hvalue)
 {
   osip_header_t *h;
   int i;
@@ -200,16 +206,15 @@ osip_message_set_body_mime (osip_message_t * sip, const char *buf)
       osip_body_free (body);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->bodies, body, -1);
   return 0;
 }
 
-int
-osip_body_parse_header (osip_body_t * body, const char *start_of_osip_body_header,
-		   const char **next_body)
+static int
+osip_body_parse_header (osip_body_t * body,
+			const char *start_of_osip_body_header,
+			const char **next_body)
 {
   const char *start_of_line;
   const char *end_of_line;
@@ -247,11 +252,11 @@ osip_body_parse_header (osip_body_t * body, const char *start_of_osip_body_heade
 	  osip_free (hname);
 	  return -1;
 	}
-      osip_strncpy (hvalue, colon_index + 1, (end_of_line - 2) - colon_index - 1);
+      osip_strncpy (hvalue, colon_index + 1,
+		    (end_of_line - 2) - colon_index - 1);
       osip_clrspace (hvalue);
 
       /* really store the header in the sip structure */
-      /* i = osip_message_set__header(sip, hname, hvalue); */
       if (osip_strncasecmp (hname, "content-type", 12) == 0)
 	i = osip_body_set_contenttype (body, hvalue);
       else
@@ -275,7 +280,7 @@ osip_body_parse_header (osip_body_t * body, const char *start_of_osip_body_heade
 int
 osip_body_parse (osip_body_t * body, const char *start_of_body)
 {
-  int i;
+  size_t i;
 
   if (body == NULL)
     return -1;
@@ -314,7 +319,9 @@ osip_body_parse_mime (osip_body_t * body, const char *start_of_body)
 
   start_of_osip_body_header = start_of_body;
 
-  i = osip_body_parse_header (body, start_of_osip_body_header, &end_of_osip_body_header);
+  i =
+    osip_body_parse_header (body, start_of_osip_body_header,
+			    &end_of_osip_body_header);
   if (i == -1)
     return -1;
 
@@ -331,13 +338,15 @@ osip_body_parse_mime (osip_body_t * body, const char *start_of_body)
 	return -1;		/* message does not end with CRLFCRLF, CRCR or LFLF */
     }
 
-  end_of_osip_body_header = end_of_osip_body_header + strlen (end_of_osip_body_header);
+  end_of_osip_body_header =
+    end_of_osip_body_header + strlen (end_of_osip_body_header);
   body->body =
-    (char *) osip_malloc (end_of_osip_body_header - start_of_osip_body_header + 1);
+    (char *) osip_malloc (end_of_osip_body_header -
+			  start_of_osip_body_header + 1);
   if (body->body == NULL)
     return -1;
   osip_strncpy (body->body, start_of_osip_body_header,
-	    end_of_osip_body_header - start_of_osip_body_header);
+		end_of_osip_body_header - start_of_osip_body_header);
 
   return 0;
 
@@ -354,7 +363,7 @@ osip_body_to_str (const osip_body_t * body, char **dest)
   char *ptr;
   int pos;
   int i;
-  unsigned length;
+  size_t length;
 
   *dest = NULL;
   if (body == NULL)
@@ -382,7 +391,7 @@ osip_body_to_str (const osip_body_t * body, char **dest)
 	}
       if (length < tmp_body - ptr + strlen (tmp) + 4)
 	{
-	  int len;
+	  size_t len;
 
 	  len = tmp_body - ptr;
 	  length = length + strlen (tmp) + 4;
@@ -411,7 +420,7 @@ osip_body_to_str (const osip_body_t * body, char **dest)
 	}
       if (length < tmp_body - ptr + strlen (tmp) + 4)
 	{
-	  int len;
+	  size_t len;
 
 	  len = tmp_body - ptr;
 	  length = length + strlen (tmp) + 4;
@@ -433,7 +442,7 @@ osip_body_to_str (const osip_body_t * body, char **dest)
     }
   if (length < tmp_body - ptr + strlen (body->body) + 4)
     {
-      int len;
+      size_t len;
 
       len = tmp_body - ptr;
       length = length + strlen (body->body) + 4;
