@@ -23,6 +23,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 
 /* adds the contact header to message.              */
 /* INPUT : const char *hvalue | value of header.    */
@@ -34,7 +35,7 @@ osip_message_set_contact (osip_message_t * sip, const char *hvalue)
   int i;
   osip_contact_t *contact;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_contact_init (&contact);
@@ -46,9 +47,7 @@ osip_message_set_contact (osip_message_t * sip, const char *hvalue)
       osip_contact_free (contact);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->contacts, contact, -1);
   return 0;			/* ok */
 }
@@ -82,7 +81,8 @@ osip_contact_init (osip_contact_t ** contact)
 /* OUTPUT: osip_contact_t *contact | structure to save results. */
 /* returns -1 on error. */
 int
-osip_message_get_contact (const osip_message_t * sip, int pos, osip_contact_t ** dest)
+osip_message_get_contact (const osip_message_t * sip, int pos,
+			  osip_contact_t ** dest)
 {
   *dest = NULL;
   if (sip == NULL)
