@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 
 int
 osip_record_route_init (osip_record_route_t ** record_route)
@@ -39,7 +40,7 @@ osip_message_set_record_route (osip_message_t * sip, const char *hvalue)
   osip_record_route_t *record_route;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_record_route_init (&record_route);
@@ -51,9 +52,7 @@ osip_message_set_record_route (osip_message_t * sip, const char *hvalue)
       osip_record_route_free (record_route);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->record_routes, record_route, -1);
   return 0;
 }
@@ -62,20 +61,23 @@ osip_message_set_record_route (osip_message_t * sip, const char *hvalue)
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
 int
-osip_message_get_record_route (const osip_message_t * sip, int pos, osip_record_route_t ** dest)
+osip_message_get_record_route (const osip_message_t * sip, int pos,
+			       osip_record_route_t ** dest)
 {
   osip_record_route_t *record_route;
 
   *dest = NULL;
   if (osip_list_size (sip->record_routes) <= pos)
     return -1;			/* does not exist */
-  record_route = (osip_record_route_t *) osip_list_get (sip->record_routes, pos);
+  record_route =
+    (osip_record_route_t *) osip_list_get (sip->record_routes, pos);
   *dest = record_route;
   return pos;
 }
 
 int
-osip_record_route_parse (osip_record_route_t * record_route, const char *hvalue)
+osip_record_route_parse (osip_record_route_t * record_route,
+			 const char *hvalue)
 {
   return osip_from_parse ((osip_from_t *) record_route, hvalue);
 }
@@ -84,12 +86,13 @@ osip_record_route_parse (osip_record_route_t * record_route, const char *hvalue)
 /* INPUT : osip_record_route_t *record_route | record_route header.  */
 /* returns -1 on error. */
 int
-osip_record_route_to_str (const osip_record_route_t * record_route, char **dest)
+osip_record_route_to_str (const osip_record_route_t * record_route,
+			  char **dest)
 {
   char *url;
   char *buf;
   int i;
-  int len;
+  size_t len;
 
   *dest = NULL;
   if ((record_route == NULL) || (record_route->url == NULL))
@@ -121,13 +124,14 @@ osip_record_route_to_str (const osip_record_route_t * record_route, char **dest)
   {
     int pos = 0;
     osip_generic_param_t *u_param;
-    int plen;
+    size_t plen;
     char *tmp;
 
     while (!osip_list_eol (record_route->gen_params, pos))
       {
 	u_param =
-	  (osip_generic_param_t *) osip_list_get (record_route->gen_params, pos);
+	  (osip_generic_param_t *) osip_list_get (record_route->gen_params,
+						  pos);
 
 	if (u_param->gvalue == NULL)
 	  plen = strlen (u_param->gname) + 2;
